# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class GetProNumSimLabIndexConfigOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'model_nodes': 'ScenarioModelNodeDto',
        'output_file': 'str',
        'rem_rate_file': 'str',
        'id': 'str'
    }

    attribute_map = {
        'code': 'code',
        'model_nodes': 'modelNodes',
        'output_file': 'outputFile',
        'rem_rate_file': 'remRateFile',
        'id': 'id'
    }

    def __init__(self, code=None, model_nodes=None, output_file=None, rem_rate_file=None, id=None, local_vars_configuration=None):  # noqa: E501
        """GetProNumSimLabIndexConfigOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._model_nodes = None
        self._output_file = None
        self._rem_rate_file = None
        self._id = None
        self.discriminator = None

        self.code = code
        self.model_nodes = model_nodes
        self.output_file = output_file
        self.rem_rate_file = rem_rate_file
        if id is not None:
            self.id = id

    @property
    def code(self):
        """Gets the code of this GetProNumSimLabIndexConfigOutput.  # noqa: E501

        指标名称  # noqa: E501

        :return: The code of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this GetProNumSimLabIndexConfigOutput.

        指标名称  # noqa: E501

        :param code: The code of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and code is None:  # noqa: E501
            raise ValueError("Invalid value for `code`, must not be `None`")  # noqa: E501

        self._code = code

    @property
    def model_nodes(self):
        """Gets the model_nodes of this GetProNumSimLabIndexConfigOutput.  # noqa: E501


        :return: The model_nodes of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :rtype: ScenarioModelNodeDto
        """
        return self._model_nodes

    @model_nodes.setter
    def model_nodes(self, model_nodes):
        """Sets the model_nodes of this GetProNumSimLabIndexConfigOutput.


        :param model_nodes: The model_nodes of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :type: ScenarioModelNodeDto
        """
        if self.local_vars_configuration.client_side_validation and model_nodes is None:  # noqa: E501
            raise ValueError("Invalid value for `model_nodes`, must not be `None`")  # noqa: E501

        self._model_nodes = model_nodes

    @property
    def output_file(self):
        """Gets the output_file of this GetProNumSimLabIndexConfigOutput.  # noqa: E501

        计算结果值,存入的文件名  # noqa: E501

        :return: The output_file of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._output_file

    @output_file.setter
    def output_file(self, output_file):
        """Sets the output_file of this GetProNumSimLabIndexConfigOutput.

        计算结果值,存入的文件名  # noqa: E501

        :param output_file: The output_file of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and output_file is None:  # noqa: E501
            raise ValueError("Invalid value for `output_file`, must not be `None`")  # noqa: E501

        self._output_file = output_file

    @property
    def rem_rate_file(self):
        """Gets the rem_rate_file of this GetProNumSimLabIndexConfigOutput.  # noqa: E501

        去除率结果值,存入的文件名  # noqa: E501

        :return: The rem_rate_file of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._rem_rate_file

    @rem_rate_file.setter
    def rem_rate_file(self, rem_rate_file):
        """Sets the rem_rate_file of this GetProNumSimLabIndexConfigOutput.

        去除率结果值,存入的文件名  # noqa: E501

        :param rem_rate_file: The rem_rate_file of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and rem_rate_file is None:  # noqa: E501
            raise ValueError("Invalid value for `rem_rate_file`, must not be `None`")  # noqa: E501

        self._rem_rate_file = rem_rate_file

    @property
    def id(self):
        """Gets the id of this GetProNumSimLabIndexConfigOutput.  # noqa: E501


        :return: The id of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this GetProNumSimLabIndexConfigOutput.


        :param id: The id of this GetProNumSimLabIndexConfigOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, GetProNumSimLabIndexConfigOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, GetProNumSimLabIndexConfigOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    digital-twin-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_digital_twin_service.configuration import Configuration


class AttributeConditionInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'attribute_key': 'str',
        'attribute_value': 'str',
        'data_type': 'int'
    }

    attribute_map = {
        'attribute_key': 'attributeKey',
        'attribute_value': 'attributeValue',
        'data_type': 'dataType'
    }

    def __init__(self, attribute_key=None, attribute_value=None, data_type=None, local_vars_configuration=None):  # noqa: E501
        """AttributeConditionInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._attribute_key = None
        self._attribute_value = None
        self._data_type = None
        self.discriminator = None

        self.attribute_key = attribute_key
        self.attribute_value = attribute_value
        self.data_type = data_type

    @property
    def attribute_key(self):
        """Gets the attribute_key of this AttributeConditionInput.  # noqa: E501

        模型中的ID列表，可为空 model muid list, can be empty  # noqa: E501

        :return: The attribute_key of this AttributeConditionInput.  # noqa: E501
        :rtype: str
        """
        return self._attribute_key

    @attribute_key.setter
    def attribute_key(self, attribute_key):
        """Sets the attribute_key of this AttributeConditionInput.

        模型中的ID列表，可为空 model muid list, can be empty  # noqa: E501

        :param attribute_key: The attribute_key of this AttributeConditionInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and attribute_key is None:  # noqa: E501
            raise ValueError("Invalid value for `attribute_key`, must not be `None`")  # noqa: E501

        self._attribute_key = attribute_key

    @property
    def attribute_value(self):
        """Gets the attribute_value of this AttributeConditionInput.  # noqa: E501

        属性值  # noqa: E501

        :return: The attribute_value of this AttributeConditionInput.  # noqa: E501
        :rtype: str
        """
        return self._attribute_value

    @attribute_value.setter
    def attribute_value(self, attribute_value):
        """Sets the attribute_value of this AttributeConditionInput.

        属性值  # noqa: E501

        :param attribute_value: The attribute_value of this AttributeConditionInput.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and attribute_value is None:  # noqa: E501
            raise ValueError("Invalid value for `attribute_value`, must not be `None`")  # noqa: E501

        self._attribute_value = attribute_value

    @property
    def data_type(self):
        """Gets the data_type of this AttributeConditionInput.  # noqa: E501

        0-StrValue 1-BoolValue 2-LongValue 3-DblValue 4-JsonValue 5-DateTimeValue   # noqa: E501

        :return: The data_type of this AttributeConditionInput.  # noqa: E501
        :rtype: int
        """
        return self._data_type

    @data_type.setter
    def data_type(self, data_type):
        """Sets the data_type of this AttributeConditionInput.

        0-StrValue 1-BoolValue 2-LongValue 3-DblValue 4-JsonValue 5-DateTimeValue   # noqa: E501

        :param data_type: The data_type of this AttributeConditionInput.  # noqa: E501
        :type: int
        """
        if self.local_vars_configuration.client_side_validation and data_type is None:  # noqa: E501
            raise ValueError("Invalid value for `data_type`, must not be `None`")  # noqa: E501
        allowed_values = [0, 1, 2, 3, 4, 5]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and data_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `data_type` ({0}), must be one of {1}"  # noqa: E501
                .format(data_type, allowed_values)
            )

        self._data_type = data_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AttributeConditionInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AttributeConditionInput):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_accident_management_service.api.accident_api import AccidentApi
from dhicn_accident_management_service.api.component_api import ComponentApi
from dhicn_accident_management_service.api.event_api import EventApi
from dhicn_accident_management_service.api.scene_api import SceneApi
from dhicn_accident_management_service.api.time_series_api import TimeSeriesApi



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class DosingParamSettingDto(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'sys_code': 'str',
        'value': 'float',
        'unit': 'str',
        'order_by': 'int',
        'is_edit_manual': 'bool',
        'is_edit_smart': 'bool',
        'name': 'str',
        'code': 'str',
        'product_line': 'str',
        'category': 'int'
    }

    attribute_map = {
        'id': 'id',
        'sys_code': 'sysCode',
        'value': 'value',
        'unit': 'unit',
        'order_by': 'orderBy',
        'is_edit_manual': 'isEditManual',
        'is_edit_smart': 'isEditSmart',
        'name': 'name',
        'code': 'code',
        'product_line': 'productLine',
        'category': 'category'
    }

    def __init__(self, id=None, sys_code=None, value=None, unit=None, order_by=None, is_edit_manual=None, is_edit_smart=None, name=None, code=None, product_line=None, category=None, local_vars_configuration=None):  # noqa: E501
        """DosingParamSettingDto - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._sys_code = None
        self._value = None
        self._unit = None
        self._order_by = None
        self._is_edit_manual = None
        self._is_edit_smart = None
        self._name = None
        self._code = None
        self._product_line = None
        self._category = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.sys_code = sys_code
        if value is not None:
            self.value = value
        self.unit = unit
        if order_by is not None:
            self.order_by = order_by
        self.is_edit_manual = is_edit_manual
        self.is_edit_smart = is_edit_smart
        self.name = name
        self.code = code
        self.product_line = product_line
        if category is not None:
            self.category = category

    @property
    def id(self):
        """Gets the id of this DosingParamSettingDto.  # noqa: E501


        :return: The id of this DosingParamSettingDto.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DosingParamSettingDto.


        :param id: The id of this DosingParamSettingDto.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def sys_code(self):
        """Gets the sys_code of this DosingParamSettingDto.  # noqa: E501

        系统代码 corresponding system code  # noqa: E501

        :return: The sys_code of this DosingParamSettingDto.  # noqa: E501
        :rtype: str
        """
        return self._sys_code

    @sys_code.setter
    def sys_code(self, sys_code):
        """Sets the sys_code of this DosingParamSettingDto.

        系统代码 corresponding system code  # noqa: E501

        :param sys_code: The sys_code of this DosingParamSettingDto.  # noqa: E501
        :type: str
        """

        self._sys_code = sys_code

    @property
    def value(self):
        """Gets the value of this DosingParamSettingDto.  # noqa: E501

        值 value  # noqa: E501

        :return: The value of this DosingParamSettingDto.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this DosingParamSettingDto.

        值 value  # noqa: E501

        :param value: The value of this DosingParamSettingDto.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def unit(self):
        """Gets the unit of this DosingParamSettingDto.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this DosingParamSettingDto.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this DosingParamSettingDto.

        单位 unit  # noqa: E501

        :param unit: The unit of this DosingParamSettingDto.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def order_by(self):
        """Gets the order_by of this DosingParamSettingDto.  # noqa: E501

        序号 display index  # noqa: E501

        :return: The order_by of this DosingParamSettingDto.  # noqa: E501
        :rtype: int
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """Sets the order_by of this DosingParamSettingDto.

        序号 display index  # noqa: E501

        :param order_by: The order_by of this DosingParamSettingDto.  # noqa: E501
        :type: int
        """

        self._order_by = order_by

    @property
    def is_edit_manual(self):
        """Gets the is_edit_manual of this DosingParamSettingDto.  # noqa: E501

        是否为手动加药参数 if support manual dosage  # noqa: E501

        :return: The is_edit_manual of this DosingParamSettingDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_edit_manual

    @is_edit_manual.setter
    def is_edit_manual(self, is_edit_manual):
        """Sets the is_edit_manual of this DosingParamSettingDto.

        是否为手动加药参数 if support manual dosage  # noqa: E501

        :param is_edit_manual: The is_edit_manual of this DosingParamSettingDto.  # noqa: E501
        :type: bool
        """

        self._is_edit_manual = is_edit_manual

    @property
    def is_edit_smart(self):
        """Gets the is_edit_smart of this DosingParamSettingDto.  # noqa: E501

        是否为智能加药参数 if support smart dosage  # noqa: E501

        :return: The is_edit_smart of this DosingParamSettingDto.  # noqa: E501
        :rtype: bool
        """
        return self._is_edit_smart

    @is_edit_smart.setter
    def is_edit_smart(self, is_edit_smart):
        """Sets the is_edit_smart of this DosingParamSettingDto.

        是否为智能加药参数 if support smart dosage  # noqa: E501

        :param is_edit_smart: The is_edit_smart of this DosingParamSettingDto.  # noqa: E501
        :type: bool
        """

        self._is_edit_smart = is_edit_smart

    @property
    def name(self):
        """Gets the name of this DosingParamSettingDto.  # noqa: E501

        参数名称 parameter name  # noqa: E501

        :return: The name of this DosingParamSettingDto.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DosingParamSettingDto.

        参数名称 parameter name  # noqa: E501

        :param name: The name of this DosingParamSettingDto.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def code(self):
        """Gets the code of this DosingParamSettingDto.  # noqa: E501

        参数编码 parameter code  # noqa: E501

        :return: The code of this DosingParamSettingDto.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this DosingParamSettingDto.

        参数编码 parameter code  # noqa: E501

        :param code: The code of this DosingParamSettingDto.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def product_line(self):
        """Gets the product_line of this DosingParamSettingDto.  # noqa: E501

        生产线 product line code  # noqa: E501

        :return: The product_line of this DosingParamSettingDto.  # noqa: E501
        :rtype: str
        """
        return self._product_line

    @product_line.setter
    def product_line(self, product_line):
        """Sets the product_line of this DosingParamSettingDto.

        生产线 product line code  # noqa: E501

        :param product_line: The product_line of this DosingParamSettingDto.  # noqa: E501
        :type: str
        """

        self._product_line = product_line

    @property
    def category(self):
        """Gets the category of this DosingParamSettingDto.  # noqa: E501

        药剂投加类别  # noqa: E501

        :return: The category of this DosingParamSettingDto.  # noqa: E501
        :rtype: int
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this DosingParamSettingDto.

        药剂投加类别  # noqa: E501

        :param category: The category of this DosingParamSettingDto.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3, 4]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and category not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `category` ({0}), must be one of {1}"  # noqa: E501
                .format(category, allowed_values)
            )

        self._category = category

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DosingParamSettingDto):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DosingParamSettingDto):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class DamGateConfigurationInputOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'configuration_name': 'str',
        'storage_max': 'float',
        'dam_gate_configurations': 'list[DamGateConfiguration]',
        'weir_adjustment_parameter': 'list[WeirAdjustmentParameter]',
        'extended_parameter': 'dict(str, str)'
    }

    attribute_map = {
        'configuration_name': 'configurationName',
        'storage_max': 'storage_Max',
        'dam_gate_configurations': 'damGateConfigurations',
        'weir_adjustment_parameter': 'weirAdjustmentParameter',
        'extended_parameter': 'extendedParameter'
    }

    def __init__(self, configuration_name=None, storage_max=None, dam_gate_configurations=None, weir_adjustment_parameter=None, extended_parameter=None, local_vars_configuration=None):  # noqa: E501
        """DamGateConfigurationInputOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._configuration_name = None
        self._storage_max = None
        self._dam_gate_configurations = None
        self._weir_adjustment_parameter = None
        self._extended_parameter = None
        self.discriminator = None

        self.configuration_name = configuration_name
        if storage_max is not None:
            self.storage_max = storage_max
        self.dam_gate_configurations = dam_gate_configurations
        self.weir_adjustment_parameter = weir_adjustment_parameter
        self.extended_parameter = extended_parameter

    @property
    def configuration_name(self):
        """Gets the configuration_name of this DamGateConfigurationInputOutput.  # noqa: E501


        :return: The configuration_name of this DamGateConfigurationInputOutput.  # noqa: E501
        :rtype: str
        """
        return self._configuration_name

    @configuration_name.setter
    def configuration_name(self, configuration_name):
        """Sets the configuration_name of this DamGateConfigurationInputOutput.


        :param configuration_name: The configuration_name of this DamGateConfigurationInputOutput.  # noqa: E501
        :type: str
        """

        self._configuration_name = configuration_name

    @property
    def storage_max(self):
        """Gets the storage_max of this DamGateConfigurationInputOutput.  # noqa: E501

        调蓄池最大体积  # noqa: E501

        :return: The storage_max of this DamGateConfigurationInputOutput.  # noqa: E501
        :rtype: float
        """
        return self._storage_max

    @storage_max.setter
    def storage_max(self, storage_max):
        """Sets the storage_max of this DamGateConfigurationInputOutput.

        调蓄池最大体积  # noqa: E501

        :param storage_max: The storage_max of this DamGateConfigurationInputOutput.  # noqa: E501
        :type: float
        """

        self._storage_max = storage_max

    @property
    def dam_gate_configurations(self):
        """Gets the dam_gate_configurations of this DamGateConfigurationInputOutput.  # noqa: E501

        20个堰门的配置数据  # noqa: E501

        :return: The dam_gate_configurations of this DamGateConfigurationInputOutput.  # noqa: E501
        :rtype: list[DamGateConfiguration]
        """
        return self._dam_gate_configurations

    @dam_gate_configurations.setter
    def dam_gate_configurations(self, dam_gate_configurations):
        """Sets the dam_gate_configurations of this DamGateConfigurationInputOutput.

        20个堰门的配置数据  # noqa: E501

        :param dam_gate_configurations: The dam_gate_configurations of this DamGateConfigurationInputOutput.  # noqa: E501
        :type: list[DamGateConfiguration]
        """

        self._dam_gate_configurations = dam_gate_configurations

    @property
    def weir_adjustment_parameter(self):
        """Gets the weir_adjustment_parameter of this DamGateConfigurationInputOutput.  # noqa: E501

        1,3,4厂过堰调整参数  # noqa: E501

        :return: The weir_adjustment_parameter of this DamGateConfigurationInputOutput.  # noqa: E501
        :rtype: list[WeirAdjustmentParameter]
        """
        return self._weir_adjustment_parameter

    @weir_adjustment_parameter.setter
    def weir_adjustment_parameter(self, weir_adjustment_parameter):
        """Sets the weir_adjustment_parameter of this DamGateConfigurationInputOutput.

        1,3,4厂过堰调整参数  # noqa: E501

        :param weir_adjustment_parameter: The weir_adjustment_parameter of this DamGateConfigurationInputOutput.  # noqa: E501
        :type: list[WeirAdjustmentParameter]
        """

        self._weir_adjustment_parameter = weir_adjustment_parameter

    @property
    def extended_parameter(self):
        """Gets the extended_parameter of this DamGateConfigurationInputOutput.  # noqa: E501

        扩展算法参数  # noqa: E501

        :return: The extended_parameter of this DamGateConfigurationInputOutput.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._extended_parameter

    @extended_parameter.setter
    def extended_parameter(self, extended_parameter):
        """Sets the extended_parameter of this DamGateConfigurationInputOutput.

        扩展算法参数  # noqa: E501

        :param extended_parameter: The extended_parameter of this DamGateConfigurationInputOutput.  # noqa: E501
        :type: dict(str, str)
        """

        self._extended_parameter = extended_parameter

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DamGateConfigurationInputOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, DamGateConfigurationInputOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class QuerySuperUsersOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'status': 'int',
        'user_name': 'str',
        'surname': 'str',
        'email': 'str',
        'department': 'str',
        'extra_properties': 'str',
        'creation_time': 'datetime',
        'tenant_id': 'str',
        'user_roles': 'list[GuidStringKeyValue]',
        'is_trial_user': 'bool',
        'trial_deadline': 'datetime',
        'phone_number': 'str',
        'tenants': 'list[TenantBelongSystemDto]'
    }

    attribute_map = {
        'id': 'id',
        'status': 'status',
        'user_name': 'userName',
        'surname': 'surname',
        'email': 'email',
        'department': 'department',
        'extra_properties': 'extraProperties',
        'creation_time': 'creationTime',
        'tenant_id': 'tenantId',
        'user_roles': 'userRoles',
        'is_trial_user': 'isTrialUser',
        'trial_deadline': 'trialDeadline',
        'phone_number': 'phoneNumber',
        'tenants': 'tenants'
    }

    def __init__(self, id=None, status=None, user_name=None, surname=None, email=None, department=None, extra_properties=None, creation_time=None, tenant_id=None, user_roles=None, is_trial_user=None, trial_deadline=None, phone_number=None, tenants=None, local_vars_configuration=None):  # noqa: E501
        """QuerySuperUsersOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._status = None
        self._user_name = None
        self._surname = None
        self._email = None
        self._department = None
        self._extra_properties = None
        self._creation_time = None
        self._tenant_id = None
        self._user_roles = None
        self._is_trial_user = None
        self._trial_deadline = None
        self._phone_number = None
        self._tenants = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if status is not None:
            self.status = status
        self.user_name = user_name
        self.surname = surname
        self.email = email
        self.department = department
        self.extra_properties = extra_properties
        if creation_time is not None:
            self.creation_time = creation_time
        self.tenant_id = tenant_id
        self.user_roles = user_roles
        if is_trial_user is not None:
            self.is_trial_user = is_trial_user
        self.trial_deadline = trial_deadline
        self.phone_number = phone_number
        self.tenants = tenants

    @property
    def id(self):
        """Gets the id of this QuerySuperUsersOutput.  # noqa: E501

        用户ID user id  # noqa: E501

        :return: The id of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this QuerySuperUsersOutput.

        用户ID user id  # noqa: E501

        :param id: The id of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def status(self):
        """Gets the status of this QuerySuperUsersOutput.  # noqa: E501

        0-Normal(normal user) 1-Frozen(frozen user) 2-Cancelled(cancelled user)   # noqa: E501

        :return: The status of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this QuerySuperUsersOutput.

        0-Normal(normal user) 1-Frozen(frozen user) 2-Cancelled(cancelled user)   # noqa: E501

        :param status: The status of this QuerySuperUsersOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and status not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `status` ({0}), must be one of {1}"  # noqa: E501
                .format(status, allowed_values)
            )

        self._status = status

    @property
    def user_name(self):
        """Gets the user_name of this QuerySuperUsersOutput.  # noqa: E501

        用户名 user name  # noqa: E501

        :return: The user_name of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._user_name

    @user_name.setter
    def user_name(self, user_name):
        """Sets the user_name of this QuerySuperUsersOutput.

        用户名 user name  # noqa: E501

        :param user_name: The user_name of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._user_name = user_name

    @property
    def surname(self):
        """Gets the surname of this QuerySuperUsersOutput.  # noqa: E501

        姓氏 surname  # noqa: E501

        :return: The surname of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._surname

    @surname.setter
    def surname(self, surname):
        """Sets the surname of this QuerySuperUsersOutput.

        姓氏 surname  # noqa: E501

        :param surname: The surname of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._surname = surname

    @property
    def email(self):
        """Gets the email of this QuerySuperUsersOutput.  # noqa: E501

        邮箱 email address  # noqa: E501

        :return: The email of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """Sets the email of this QuerySuperUsersOutput.

        邮箱 email address  # noqa: E501

        :param email: The email of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._email = email

    @property
    def department(self):
        """Gets the department of this QuerySuperUsersOutput.  # noqa: E501

        所属单位 working department  # noqa: E501

        :return: The department of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """Sets the department of this QuerySuperUsersOutput.

        所属单位 working department  # noqa: E501

        :param department: The department of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._department = department

    @property
    def extra_properties(self):
        """Gets the extra_properties of this QuerySuperUsersOutput.  # noqa: E501

        额外属性 extra properties  # noqa: E501

        :return: The extra_properties of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._extra_properties

    @extra_properties.setter
    def extra_properties(self, extra_properties):
        """Sets the extra_properties of this QuerySuperUsersOutput.

        额外属性 extra properties  # noqa: E501

        :param extra_properties: The extra_properties of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._extra_properties = extra_properties

    @property
    def creation_time(self):
        """Gets the creation_time of this QuerySuperUsersOutput.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The creation_time of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_time

    @creation_time.setter
    def creation_time(self, creation_time):
        """Sets the creation_time of this QuerySuperUsersOutput.

        创建时间 create time  # noqa: E501

        :param creation_time: The creation_time of this QuerySuperUsersOutput.  # noqa: E501
        :type: datetime
        """

        self._creation_time = creation_time

    @property
    def tenant_id(self):
        """Gets the tenant_id of this QuerySuperUsersOutput.  # noqa: E501

        租户ID tenant id  # noqa: E501

        :return: The tenant_id of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this QuerySuperUsersOutput.

        租户ID tenant id  # noqa: E501

        :param tenant_id: The tenant_id of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._tenant_id = tenant_id

    @property
    def user_roles(self):
        """Gets the user_roles of this QuerySuperUsersOutput.  # noqa: E501

        用户角色 user roles  # noqa: E501

        :return: The user_roles of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: list[GuidStringKeyValue]
        """
        return self._user_roles

    @user_roles.setter
    def user_roles(self, user_roles):
        """Sets the user_roles of this QuerySuperUsersOutput.

        用户角色 user roles  # noqa: E501

        :param user_roles: The user_roles of this QuerySuperUsersOutput.  # noqa: E501
        :type: list[GuidStringKeyValue]
        """

        self._user_roles = user_roles

    @property
    def is_trial_user(self):
        """Gets the is_trial_user of this QuerySuperUsersOutput.  # noqa: E501

        是否试用用户 if it is a trial user  # noqa: E501

        :return: The is_trial_user of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: bool
        """
        return self._is_trial_user

    @is_trial_user.setter
    def is_trial_user(self, is_trial_user):
        """Sets the is_trial_user of this QuerySuperUsersOutput.

        是否试用用户 if it is a trial user  # noqa: E501

        :param is_trial_user: The is_trial_user of this QuerySuperUsersOutput.  # noqa: E501
        :type: bool
        """

        self._is_trial_user = is_trial_user

    @property
    def trial_deadline(self):
        """Gets the trial_deadline of this QuerySuperUsersOutput.  # noqa: E501

        试用截止日期 trial deadline  # noqa: E501

        :return: The trial_deadline of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._trial_deadline

    @trial_deadline.setter
    def trial_deadline(self, trial_deadline):
        """Sets the trial_deadline of this QuerySuperUsersOutput.

        试用截止日期 trial deadline  # noqa: E501

        :param trial_deadline: The trial_deadline of this QuerySuperUsersOutput.  # noqa: E501
        :type: datetime
        """

        self._trial_deadline = trial_deadline

    @property
    def phone_number(self):
        """Gets the phone_number of this QuerySuperUsersOutput.  # noqa: E501

        电话号码 phonenumber  # noqa: E501

        :return: The phone_number of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this QuerySuperUsersOutput.

        电话号码 phonenumber  # noqa: E501

        :param phone_number: The phone_number of this QuerySuperUsersOutput.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    @property
    def tenants(self):
        """Gets the tenants of this QuerySuperUsersOutput.  # noqa: E501

        租户信息列表 tenants  # noqa: E501

        :return: The tenants of this QuerySuperUsersOutput.  # noqa: E501
        :rtype: list[TenantBelongSystemDto]
        """
        return self._tenants

    @tenants.setter
    def tenants(self, tenants):
        """Sets the tenants of this QuerySuperUsersOutput.

        租户信息列表 tenants  # noqa: E501

        :param tenants: The tenants of this QuerySuperUsersOutput.  # noqa: E501
        :type: list[TenantBelongSystemDto]
        """

        self._tenants = tenants

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, QuerySuperUsersOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, QuerySuperUsersOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-main-bus-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_data_bus_service.configuration import Configuration


class PredictAlarmOut(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'code': 'str',
        'prediction_time': 'datetime',
        'value': 'float',
        'message': 'str',
        'detail_message': 'str',
        'unit': 'str',
        'alarm_type': 'int'
    }

    attribute_map = {
        'code': 'code',
        'prediction_time': 'predictionTime',
        'value': 'value',
        'message': 'message',
        'detail_message': 'detailMessage',
        'unit': 'unit',
        'alarm_type': 'alarmType'
    }

    def __init__(self, code=None, prediction_time=None, value=None, message=None, detail_message=None, unit=None, alarm_type=None, local_vars_configuration=None):  # noqa: E501
        """PredictAlarmOut - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._code = None
        self._prediction_time = None
        self._value = None
        self._message = None
        self._detail_message = None
        self._unit = None
        self._alarm_type = None
        self.discriminator = None

        self.code = code
        if prediction_time is not None:
            self.prediction_time = prediction_time
        if value is not None:
            self.value = value
        self.message = message
        self.detail_message = detail_message
        self.unit = unit
        if alarm_type is not None:
            self.alarm_type = alarm_type

    @property
    def code(self):
        """Gets the code of this PredictAlarmOut.  # noqa: E501

        指标 indicator code  # noqa: E501

        :return: The code of this PredictAlarmOut.  # noqa: E501
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """Sets the code of this PredictAlarmOut.

        指标 indicator code  # noqa: E501

        :param code: The code of this PredictAlarmOut.  # noqa: E501
        :type: str
        """

        self._code = code

    @property
    def prediction_time(self):
        """Gets the prediction_time of this PredictAlarmOut.  # noqa: E501

        时刻 alarm time  # noqa: E501

        :return: The prediction_time of this PredictAlarmOut.  # noqa: E501
        :rtype: datetime
        """
        return self._prediction_time

    @prediction_time.setter
    def prediction_time(self, prediction_time):
        """Sets the prediction_time of this PredictAlarmOut.

        时刻 alarm time  # noqa: E501

        :param prediction_time: The prediction_time of this PredictAlarmOut.  # noqa: E501
        :type: datetime
        """

        self._prediction_time = prediction_time

    @property
    def value(self):
        """Gets the value of this PredictAlarmOut.  # noqa: E501

        预测值 value  # noqa: E501

        :return: The value of this PredictAlarmOut.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this PredictAlarmOut.

        预测值 value  # noqa: E501

        :param value: The value of this PredictAlarmOut.  # noqa: E501
        :type: float
        """

        self._value = value

    @property
    def message(self):
        """Gets the message of this PredictAlarmOut.  # noqa: E501

        预警信息 alarm message  # noqa: E501

        :return: The message of this PredictAlarmOut.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this PredictAlarmOut.

        预警信息 alarm message  # noqa: E501

        :param message: The message of this PredictAlarmOut.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def detail_message(self):
        """Gets the detail_message of this PredictAlarmOut.  # noqa: E501

        详细预警信息 alarm message detail  # noqa: E501

        :return: The detail_message of this PredictAlarmOut.  # noqa: E501
        :rtype: str
        """
        return self._detail_message

    @detail_message.setter
    def detail_message(self, detail_message):
        """Sets the detail_message of this PredictAlarmOut.

        详细预警信息 alarm message detail  # noqa: E501

        :param detail_message: The detail_message of this PredictAlarmOut.  # noqa: E501
        :type: str
        """

        self._detail_message = detail_message

    @property
    def unit(self):
        """Gets the unit of this PredictAlarmOut.  # noqa: E501

        单位 unit  # noqa: E501

        :return: The unit of this PredictAlarmOut.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this PredictAlarmOut.

        单位 unit  # noqa: E501

        :param unit: The unit of this PredictAlarmOut.  # noqa: E501
        :type: str
        """

        self._unit = unit

    @property
    def alarm_type(self):
        """Gets the alarm_type of this PredictAlarmOut.  # noqa: E501

        预警类型 alarm type  # noqa: E501

        :return: The alarm_type of this PredictAlarmOut.  # noqa: E501
        :rtype: int
        """
        return self._alarm_type

    @alarm_type.setter
    def alarm_type(self, alarm_type):
        """Sets the alarm_type of this PredictAlarmOut.

        预警类型 alarm type  # noqa: E501

        :param alarm_type: The alarm_type of this PredictAlarmOut.  # noqa: E501
        :type: int
        """
        allowed_values = [0, 1, 2]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and alarm_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `alarm_type` ({0}), must be one of {1}"  # noqa: E501
                .format(alarm_type, allowed_values)
            )

        self._alarm_type = alarm_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PredictAlarmOut):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PredictAlarmOut):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class SavePipeBurstInfoInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'accident_name': 'str',
        'scenario_id': 'str',
        'pipe_burst_events': 'list[WdEventDetailInput]',
        'gis_valve_info_list': 'list[GisValveInfo]'
    }

    attribute_map = {
        'accident_name': 'accidentName',
        'scenario_id': 'scenarioId',
        'pipe_burst_events': 'pipeBurstEvents',
        'gis_valve_info_list': 'gisValveInfoList'
    }

    def __init__(self, accident_name=None, scenario_id=None, pipe_burst_events=None, gis_valve_info_list=None, local_vars_configuration=None):  # noqa: E501
        """SavePipeBurstInfoInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._accident_name = None
        self._scenario_id = None
        self._pipe_burst_events = None
        self._gis_valve_info_list = None
        self.discriminator = None

        self.accident_name = accident_name
        if scenario_id is not None:
            self.scenario_id = scenario_id
        self.pipe_burst_events = pipe_burst_events
        self.gis_valve_info_list = gis_valve_info_list

    @property
    def accident_name(self):
        """Gets the accident_name of this SavePipeBurstInfoInput.  # noqa: E501

        事故名称  # noqa: E501

        :return: The accident_name of this SavePipeBurstInfoInput.  # noqa: E501
        :rtype: str
        """
        return self._accident_name

    @accident_name.setter
    def accident_name(self, accident_name):
        """Sets the accident_name of this SavePipeBurstInfoInput.

        事故名称  # noqa: E501

        :param accident_name: The accident_name of this SavePipeBurstInfoInput.  # noqa: E501
        :type: str
        """

        self._accident_name = accident_name

    @property
    def scenario_id(self):
        """Gets the scenario_id of this SavePipeBurstInfoInput.  # noqa: E501

        方案id  # noqa: E501

        :return: The scenario_id of this SavePipeBurstInfoInput.  # noqa: E501
        :rtype: str
        """
        return self._scenario_id

    @scenario_id.setter
    def scenario_id(self, scenario_id):
        """Sets the scenario_id of this SavePipeBurstInfoInput.

        方案id  # noqa: E501

        :param scenario_id: The scenario_id of this SavePipeBurstInfoInput.  # noqa: E501
        :type: str
        """

        self._scenario_id = scenario_id

    @property
    def pipe_burst_events(self):
        """Gets the pipe_burst_events of this SavePipeBurstInfoInput.  # noqa: E501

        爆管事件列表  # noqa: E501

        :return: The pipe_burst_events of this SavePipeBurstInfoInput.  # noqa: E501
        :rtype: list[WdEventDetailInput]
        """
        return self._pipe_burst_events

    @pipe_burst_events.setter
    def pipe_burst_events(self, pipe_burst_events):
        """Sets the pipe_burst_events of this SavePipeBurstInfoInput.

        爆管事件列表  # noqa: E501

        :param pipe_burst_events: The pipe_burst_events of this SavePipeBurstInfoInput.  # noqa: E501
        :type: list[WdEventDetailInput]
        """

        self._pipe_burst_events = pipe_burst_events

    @property
    def gis_valve_info_list(self):
        """Gets the gis_valve_info_list of this SavePipeBurstInfoInput.  # noqa: E501

        阀门信息  # noqa: E501

        :return: The gis_valve_info_list of this SavePipeBurstInfoInput.  # noqa: E501
        :rtype: list[GisValveInfo]
        """
        return self._gis_valve_info_list

    @gis_valve_info_list.setter
    def gis_valve_info_list(self, gis_valve_info_list):
        """Sets the gis_valve_info_list of this SavePipeBurstInfoInput.

        阀门信息  # noqa: E501

        :param gis_valve_info_list: The gis_valve_info_list of this SavePipeBurstInfoInput.  # noqa: E501
        :type: list[GisValveInfo]
        """

        self._gis_valve_info_list = gis_valve_info_list

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SavePipeBurstInfoInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SavePipeBurstInfoInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    identity-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_identity_service.configuration import Configuration


class SaveBasicSettingsInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'surname': 'str',
        'department': 'str',
        'profile': 'str',
        'phone_number': 'str'
    }

    attribute_map = {
        'surname': 'surname',
        'department': 'department',
        'profile': 'profile',
        'phone_number': 'phoneNumber'
    }

    def __init__(self, surname=None, department=None, profile=None, phone_number=None, local_vars_configuration=None):  # noqa: E501
        """SaveBasicSettingsInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._surname = None
        self._department = None
        self._profile = None
        self._phone_number = None
        self.discriminator = None

        self.surname = surname
        self.department = department
        self.profile = profile
        self.phone_number = phone_number

    @property
    def surname(self):
        """Gets the surname of this SaveBasicSettingsInput.  # noqa: E501

        真实姓名 real name  # noqa: E501

        :return: The surname of this SaveBasicSettingsInput.  # noqa: E501
        :rtype: str
        """
        return self._surname

    @surname.setter
    def surname(self, surname):
        """Sets the surname of this SaveBasicSettingsInput.

        真实姓名 real name  # noqa: E501

        :param surname: The surname of this SaveBasicSettingsInput.  # noqa: E501
        :type: str
        """

        self._surname = surname

    @property
    def department(self):
        """Gets the department of this SaveBasicSettingsInput.  # noqa: E501

        所属部门 working department  # noqa: E501

        :return: The department of this SaveBasicSettingsInput.  # noqa: E501
        :rtype: str
        """
        return self._department

    @department.setter
    def department(self, department):
        """Sets the department of this SaveBasicSettingsInput.

        所属部门 working department  # noqa: E501

        :param department: The department of this SaveBasicSettingsInput.  # noqa: E501
        :type: str
        """

        self._department = department

    @property
    def profile(self):
        """Gets the profile of this SaveBasicSettingsInput.  # noqa: E501

        个人简介 personal profile  # noqa: E501

        :return: The profile of this SaveBasicSettingsInput.  # noqa: E501
        :rtype: str
        """
        return self._profile

    @profile.setter
    def profile(self, profile):
        """Sets the profile of this SaveBasicSettingsInput.

        个人简介 personal profile  # noqa: E501

        :param profile: The profile of this SaveBasicSettingsInput.  # noqa: E501
        :type: str
        """

        self._profile = profile

    @property
    def phone_number(self):
        """Gets the phone_number of this SaveBasicSettingsInput.  # noqa: E501

        电话号码 phone number  # noqa: E501

        :return: The phone_number of this SaveBasicSettingsInput.  # noqa: E501
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this SaveBasicSettingsInput.

        电话号码 phone number  # noqa: E501

        :param phone_number: The phone_number of this SaveBasicSettingsInput.  # noqa: E501
        :type: str
        """

        self._phone_number = phone_number

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SaveBasicSettingsInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SaveBasicSettingsInput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-configuration-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_model_configuration_service.configuration import Configuration


class ClassifyLegendInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'grade': 'int',
        'max_value': 'float',
        'min_value': 'float',
        'red': 'int',
        'green': 'int',
        'blue': 'int',
        'description': 'str'
    }

    attribute_map = {
        'grade': 'grade',
        'max_value': 'maxValue',
        'min_value': 'minValue',
        'red': 'red',
        'green': 'green',
        'blue': 'blue',
        'description': 'description'
    }

    def __init__(self, grade=None, max_value=None, min_value=None, red=None, green=None, blue=None, description=None, local_vars_configuration=None):  # noqa: E501
        """ClassifyLegendInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._grade = None
        self._max_value = None
        self._min_value = None
        self._red = None
        self._green = None
        self._blue = None
        self._description = None
        self.discriminator = None

        if grade is not None:
            self.grade = grade
        if max_value is not None:
            self.max_value = max_value
        if min_value is not None:
            self.min_value = min_value
        if red is not None:
            self.red = red
        if green is not None:
            self.green = green
        if blue is not None:
            self.blue = blue
        self.description = description

    @property
    def grade(self):
        """Gets the grade of this ClassifyLegendInfo.  # noqa: E501

        等级序号 grade  # noqa: E501

        :return: The grade of this ClassifyLegendInfo.  # noqa: E501
        :rtype: int
        """
        return self._grade

    @grade.setter
    def grade(self, grade):
        """Sets the grade of this ClassifyLegendInfo.

        等级序号 grade  # noqa: E501

        :param grade: The grade of this ClassifyLegendInfo.  # noqa: E501
        :type: int
        """

        self._grade = grade

    @property
    def max_value(self):
        """Gets the max_value of this ClassifyLegendInfo.  # noqa: E501

        最大值 max value  # noqa: E501

        :return: The max_value of this ClassifyLegendInfo.  # noqa: E501
        :rtype: float
        """
        return self._max_value

    @max_value.setter
    def max_value(self, max_value):
        """Sets the max_value of this ClassifyLegendInfo.

        最大值 max value  # noqa: E501

        :param max_value: The max_value of this ClassifyLegendInfo.  # noqa: E501
        :type: float
        """

        self._max_value = max_value

    @property
    def min_value(self):
        """Gets the min_value of this ClassifyLegendInfo.  # noqa: E501

        最小值 min value  # noqa: E501

        :return: The min_value of this ClassifyLegendInfo.  # noqa: E501
        :rtype: float
        """
        return self._min_value

    @min_value.setter
    def min_value(self, min_value):
        """Sets the min_value of this ClassifyLegendInfo.

        最小值 min value  # noqa: E501

        :param min_value: The min_value of this ClassifyLegendInfo.  # noqa: E501
        :type: float
        """

        self._min_value = min_value

    @property
    def red(self):
        """Gets the red of this ClassifyLegendInfo.  # noqa: E501

        RGB颜色的红色值 red value in rgb color (0-255)  # noqa: E501

        :return: The red of this ClassifyLegendInfo.  # noqa: E501
        :rtype: int
        """
        return self._red

    @red.setter
    def red(self, red):
        """Sets the red of this ClassifyLegendInfo.

        RGB颜色的红色值 red value in rgb color (0-255)  # noqa: E501

        :param red: The red of this ClassifyLegendInfo.  # noqa: E501
        :type: int
        """

        self._red = red

    @property
    def green(self):
        """Gets the green of this ClassifyLegendInfo.  # noqa: E501

        RGB颜色的绿色值 green value in rgb color (0-255)  # noqa: E501

        :return: The green of this ClassifyLegendInfo.  # noqa: E501
        :rtype: int
        """
        return self._green

    @green.setter
    def green(self, green):
        """Sets the green of this ClassifyLegendInfo.

        RGB颜色的绿色值 green value in rgb color (0-255)  # noqa: E501

        :param green: The green of this ClassifyLegendInfo.  # noqa: E501
        :type: int
        """

        self._green = green

    @property
    def blue(self):
        """Gets the blue of this ClassifyLegendInfo.  # noqa: E501

        RGB颜色的蓝色值 blue value in rgb color (0-255)  # noqa: E501

        :return: The blue of this ClassifyLegendInfo.  # noqa: E501
        :rtype: int
        """
        return self._blue

    @blue.setter
    def blue(self, blue):
        """Sets the blue of this ClassifyLegendInfo.

        RGB颜色的蓝色值 blue value in rgb color (0-255)  # noqa: E501

        :param blue: The blue of this ClassifyLegendInfo.  # noqa: E501
        :type: int
        """

        self._blue = blue

    @property
    def description(self):
        """Gets the description of this ClassifyLegendInfo.  # noqa: E501

        描述 description  # noqa: E501

        :return: The description of this ClassifyLegendInfo.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ClassifyLegendInfo.

        描述 description  # noqa: E501

        :param description: The description of this ClassifyLegendInfo.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ClassifyLegendInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ClassifyLegendInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wwtp_infrastructure_service.configuration import Configuration


class TemplateOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'model_name': 'str',
        'model_type': 'int',
        'model_file_name': 'str',
        'create_time': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'model_name': 'modelName',
        'model_type': 'modelType',
        'model_file_name': 'modelFileName',
        'create_time': 'createTime'
    }

    def __init__(self, id=None, model_name=None, model_type=None, model_file_name=None, create_time=None, local_vars_configuration=None):  # noqa: E501
        """TemplateOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._model_name = None
        self._model_type = None
        self._model_file_name = None
        self._create_time = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.model_name = model_name
        if model_type is not None:
            self.model_type = model_type
        self.model_file_name = model_file_name
        if create_time is not None:
            self.create_time = create_time

    @property
    def id(self):
        """Gets the id of this TemplateOutput.  # noqa: E501

        模板方案ID template scenario id  # noqa: E501

        :return: The id of this TemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TemplateOutput.

        模板方案ID template scenario id  # noqa: E501

        :param id: The id of this TemplateOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def model_name(self):
        """Gets the model_name of this TemplateOutput.  # noqa: E501

        模型名称（即模板方案名称） model name as well as template scenario name  # noqa: E501

        :return: The model_name of this TemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_name

    @model_name.setter
    def model_name(self, model_name):
        """Sets the model_name of this TemplateOutput.

        模型名称（即模板方案名称） model name as well as template scenario name  # noqa: E501

        :param model_name: The model_name of this TemplateOutput.  # noqa: E501
        :type: str
        """

        self._model_name = model_name

    @property
    def model_type(self):
        """Gets the model_type of this TemplateOutput.  # noqa: E501

        模型类型，分为WWTP, WWTPOptim, WWTPMLab model type including WWTP, WWTPOptim, WWTPMLab  # noqa: E501

        :return: The model_type of this TemplateOutput.  # noqa: E501
        :rtype: int
        """
        return self._model_type

    @model_type.setter
    def model_type(self, model_type):
        """Sets the model_type of this TemplateOutput.

        模型类型，分为WWTP, WWTPOptim, WWTPMLab model type including WWTP, WWTPOptim, WWTPMLab  # noqa: E501

        :param model_type: The model_type of this TemplateOutput.  # noqa: E501
        :type: int
        """
        allowed_values = [1, 2, 3]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and model_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `model_type` ({0}), must be one of {1}"  # noqa: E501
                .format(model_type, allowed_values)
            )

        self._model_type = model_type

    @property
    def model_file_name(self):
        """Gets the model_file_name of this TemplateOutput.  # noqa: E501

        模板文件名称（压缩文件） compressed model file name  # noqa: E501

        :return: The model_file_name of this TemplateOutput.  # noqa: E501
        :rtype: str
        """
        return self._model_file_name

    @model_file_name.setter
    def model_file_name(self, model_file_name):
        """Sets the model_file_name of this TemplateOutput.

        模板文件名称（压缩文件） compressed model file name  # noqa: E501

        :param model_file_name: The model_file_name of this TemplateOutput.  # noqa: E501
        :type: str
        """

        self._model_file_name = model_file_name

    @property
    def create_time(self):
        """Gets the create_time of this TemplateOutput.  # noqa: E501

        创建时间 create time  # noqa: E501

        :return: The create_time of this TemplateOutput.  # noqa: E501
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """Sets the create_time of this TemplateOutput.

        创建时间 create time  # noqa: E501

        :param create_time: The create_time of this TemplateOutput.  # noqa: E501
        :type: datetime
        """

        self._create_time = create_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TemplateOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TemplateOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class PipeResult(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipe_id': 'str',
        'diameter': 'float',
        'length': 'float',
        'abs_flow': 'float',
        'headloss': 'float',
        'velocity_max': 'float',
        'velocity_change': 'float',
        'shear_stress': 'float',
        'criteria_type': 'str',
        'criteria_value': 'float',
        'criteria_pct': 'str',
        'flushing_time': 'float',
        'flushing_pct': 'float',
        'comment': 'str'
    }

    attribute_map = {
        'pipe_id': 'pipeID',
        'diameter': 'diameter',
        'length': 'length',
        'abs_flow': 'absFlow',
        'headloss': 'headloss',
        'velocity_max': 'velocityMax',
        'velocity_change': 'velocityChange',
        'shear_stress': 'shearStress',
        'criteria_type': 'criteriaType',
        'criteria_value': 'criteriaValue',
        'criteria_pct': 'criteriaPct',
        'flushing_time': 'flushingTime',
        'flushing_pct': 'flushingPct',
        'comment': 'comment'
    }

    def __init__(self, pipe_id=None, diameter=None, length=None, abs_flow=None, headloss=None, velocity_max=None, velocity_change=None, shear_stress=None, criteria_type=None, criteria_value=None, criteria_pct=None, flushing_time=None, flushing_pct=None, comment=None, local_vars_configuration=None):  # noqa: E501
        """PipeResult - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pipe_id = None
        self._diameter = None
        self._length = None
        self._abs_flow = None
        self._headloss = None
        self._velocity_max = None
        self._velocity_change = None
        self._shear_stress = None
        self._criteria_type = None
        self._criteria_value = None
        self._criteria_pct = None
        self._flushing_time = None
        self._flushing_pct = None
        self._comment = None
        self.discriminator = None

        self.pipe_id = pipe_id
        if diameter is not None:
            self.diameter = diameter
        if length is not None:
            self.length = length
        if abs_flow is not None:
            self.abs_flow = abs_flow
        if headloss is not None:
            self.headloss = headloss
        if velocity_max is not None:
            self.velocity_max = velocity_max
        if velocity_change is not None:
            self.velocity_change = velocity_change
        if shear_stress is not None:
            self.shear_stress = shear_stress
        self.criteria_type = criteria_type
        if criteria_value is not None:
            self.criteria_value = criteria_value
        self.criteria_pct = criteria_pct
        if flushing_time is not None:
            self.flushing_time = flushing_time
        if flushing_pct is not None:
            self.flushing_pct = flushing_pct
        self.comment = comment

    @property
    def pipe_id(self):
        """Gets the pipe_id of this PipeResult.  # noqa: E501


        :return: The pipe_id of this PipeResult.  # noqa: E501
        :rtype: str
        """
        return self._pipe_id

    @pipe_id.setter
    def pipe_id(self, pipe_id):
        """Sets the pipe_id of this PipeResult.


        :param pipe_id: The pipe_id of this PipeResult.  # noqa: E501
        :type: str
        """

        self._pipe_id = pipe_id

    @property
    def diameter(self):
        """Gets the diameter of this PipeResult.  # noqa: E501


        :return: The diameter of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._diameter

    @diameter.setter
    def diameter(self, diameter):
        """Sets the diameter of this PipeResult.


        :param diameter: The diameter of this PipeResult.  # noqa: E501
        :type: float
        """

        self._diameter = diameter

    @property
    def length(self):
        """Gets the length of this PipeResult.  # noqa: E501


        :return: The length of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this PipeResult.


        :param length: The length of this PipeResult.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def abs_flow(self):
        """Gets the abs_flow of this PipeResult.  # noqa: E501


        :return: The abs_flow of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._abs_flow

    @abs_flow.setter
    def abs_flow(self, abs_flow):
        """Sets the abs_flow of this PipeResult.


        :param abs_flow: The abs_flow of this PipeResult.  # noqa: E501
        :type: float
        """

        self._abs_flow = abs_flow

    @property
    def headloss(self):
        """Gets the headloss of this PipeResult.  # noqa: E501


        :return: The headloss of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._headloss

    @headloss.setter
    def headloss(self, headloss):
        """Sets the headloss of this PipeResult.


        :param headloss: The headloss of this PipeResult.  # noqa: E501
        :type: float
        """

        self._headloss = headloss

    @property
    def velocity_max(self):
        """Gets the velocity_max of this PipeResult.  # noqa: E501


        :return: The velocity_max of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._velocity_max

    @velocity_max.setter
    def velocity_max(self, velocity_max):
        """Sets the velocity_max of this PipeResult.


        :param velocity_max: The velocity_max of this PipeResult.  # noqa: E501
        :type: float
        """

        self._velocity_max = velocity_max

    @property
    def velocity_change(self):
        """Gets the velocity_change of this PipeResult.  # noqa: E501


        :return: The velocity_change of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._velocity_change

    @velocity_change.setter
    def velocity_change(self, velocity_change):
        """Sets the velocity_change of this PipeResult.


        :param velocity_change: The velocity_change of this PipeResult.  # noqa: E501
        :type: float
        """

        self._velocity_change = velocity_change

    @property
    def shear_stress(self):
        """Gets the shear_stress of this PipeResult.  # noqa: E501


        :return: The shear_stress of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._shear_stress

    @shear_stress.setter
    def shear_stress(self, shear_stress):
        """Sets the shear_stress of this PipeResult.


        :param shear_stress: The shear_stress of this PipeResult.  # noqa: E501
        :type: float
        """

        self._shear_stress = shear_stress

    @property
    def criteria_type(self):
        """Gets the criteria_type of this PipeResult.  # noqa: E501


        :return: The criteria_type of this PipeResult.  # noqa: E501
        :rtype: str
        """
        return self._criteria_type

    @criteria_type.setter
    def criteria_type(self, criteria_type):
        """Sets the criteria_type of this PipeResult.


        :param criteria_type: The criteria_type of this PipeResult.  # noqa: E501
        :type: str
        """

        self._criteria_type = criteria_type

    @property
    def criteria_value(self):
        """Gets the criteria_value of this PipeResult.  # noqa: E501


        :return: The criteria_value of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._criteria_value

    @criteria_value.setter
    def criteria_value(self, criteria_value):
        """Sets the criteria_value of this PipeResult.


        :param criteria_value: The criteria_value of this PipeResult.  # noqa: E501
        :type: float
        """

        self._criteria_value = criteria_value

    @property
    def criteria_pct(self):
        """Gets the criteria_pct of this PipeResult.  # noqa: E501


        :return: The criteria_pct of this PipeResult.  # noqa: E501
        :rtype: str
        """
        return self._criteria_pct

    @criteria_pct.setter
    def criteria_pct(self, criteria_pct):
        """Sets the criteria_pct of this PipeResult.


        :param criteria_pct: The criteria_pct of this PipeResult.  # noqa: E501
        :type: str
        """

        self._criteria_pct = criteria_pct

    @property
    def flushing_time(self):
        """Gets the flushing_time of this PipeResult.  # noqa: E501


        :return: The flushing_time of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._flushing_time

    @flushing_time.setter
    def flushing_time(self, flushing_time):
        """Sets the flushing_time of this PipeResult.


        :param flushing_time: The flushing_time of this PipeResult.  # noqa: E501
        :type: float
        """

        self._flushing_time = flushing_time

    @property
    def flushing_pct(self):
        """Gets the flushing_pct of this PipeResult.  # noqa: E501


        :return: The flushing_pct of this PipeResult.  # noqa: E501
        :rtype: float
        """
        return self._flushing_pct

    @flushing_pct.setter
    def flushing_pct(self, flushing_pct):
        """Sets the flushing_pct of this PipeResult.


        :param flushing_pct: The flushing_pct of this PipeResult.  # noqa: E501
        :type: float
        """

        self._flushing_pct = flushing_pct

    @property
    def comment(self):
        """Gets the comment of this PipeResult.  # noqa: E501


        :return: The comment of this PipeResult.  # noqa: E501
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this PipeResult.


        :param comment: The comment of this PipeResult.  # noqa: E501
        :type: str
        """

        self._comment = comment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipeResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PipeResult):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class LogSimulationItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'time': 'str',
        'progress': 'float',
        'message': 'str',
        'model_state': 'ModelStateEnum',
        'error_msg': 'str'
    }

    attribute_map = {
        'time': 'time',
        'progress': 'progress',
        'message': 'message',
        'model_state': 'modelState',
        'error_msg': 'errorMsg'
    }

    def __init__(self, time=None, progress=None, message=None, model_state=None, error_msg=None, local_vars_configuration=None):  # noqa: E501
        """LogSimulationItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._time = None
        self._progress = None
        self._message = None
        self._model_state = None
        self._error_msg = None
        self.discriminator = None

        self.time = time
        if progress is not None:
            self.progress = progress
        self.message = message
        if model_state is not None:
            self.model_state = model_state
        self.error_msg = error_msg

    @property
    def time(self):
        """Gets the time of this LogSimulationItem.  # noqa: E501

        日志记录时间 log time  # noqa: E501

        :return: The time of this LogSimulationItem.  # noqa: E501
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """Sets the time of this LogSimulationItem.

        日志记录时间 log time  # noqa: E501

        :param time: The time of this LogSimulationItem.  # noqa: E501
        :type: str
        """

        self._time = time

    @property
    def progress(self):
        """Gets the progress of this LogSimulationItem.  # noqa: E501

        计算进度 calculation progress  # noqa: E501

        :return: The progress of this LogSimulationItem.  # noqa: E501
        :rtype: float
        """
        return self._progress

    @progress.setter
    def progress(self, progress):
        """Sets the progress of this LogSimulationItem.

        计算进度 calculation progress  # noqa: E501

        :param progress: The progress of this LogSimulationItem.  # noqa: E501
        :type: float
        """

        self._progress = progress

    @property
    def message(self):
        """Gets the message of this LogSimulationItem.  # noqa: E501

        消息 remark message  # noqa: E501

        :return: The message of this LogSimulationItem.  # noqa: E501
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """Sets the message of this LogSimulationItem.

        消息 remark message  # noqa: E501

        :param message: The message of this LogSimulationItem.  # noqa: E501
        :type: str
        """

        self._message = message

    @property
    def model_state(self):
        """Gets the model_state of this LogSimulationItem.  # noqa: E501


        :return: The model_state of this LogSimulationItem.  # noqa: E501
        :rtype: ModelStateEnum
        """
        return self._model_state

    @model_state.setter
    def model_state(self, model_state):
        """Sets the model_state of this LogSimulationItem.


        :param model_state: The model_state of this LogSimulationItem.  # noqa: E501
        :type: ModelStateEnum
        """

        self._model_state = model_state

    @property
    def error_msg(self):
        """Gets the error_msg of this LogSimulationItem.  # noqa: E501

        错误信息 error message  # noqa: E501

        :return: The error_msg of this LogSimulationItem.  # noqa: E501
        :rtype: str
        """
        return self._error_msg

    @error_msg.setter
    def error_msg(self, error_msg):
        """Sets the error_msg of this LogSimulationItem.

        错误信息 error message  # noqa: E501

        :param error_msg: The error_msg of this LogSimulationItem.  # noqa: E501
        :type: str
        """

        self._error_msg = error_msg

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogSimulationItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LogSimulationItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    wd-domain-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_wd_domain_service.configuration import Configuration


class PipeRiskPropertyOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'pipe_model_id': 'str',
        'pipe_material': 'float',
        'pipe_age': 'float',
        'interface_type': 'float',
        'pipe_broken_num': 'float',
        'earthing_type': 'float',
        'road_load': 'float',
        'pressure_wave': 'float'
    }

    attribute_map = {
        'id': 'id',
        'pipe_model_id': 'pipeModelId',
        'pipe_material': 'pipeMaterial',
        'pipe_age': 'pipeAge',
        'interface_type': 'interfaceType',
        'pipe_broken_num': 'pipeBrokenNum',
        'earthing_type': 'earthingType',
        'road_load': 'roadLoad',
        'pressure_wave': 'pressureWave'
    }

    def __init__(self, id=None, pipe_model_id=None, pipe_material=None, pipe_age=None, interface_type=None, pipe_broken_num=None, earthing_type=None, road_load=None, pressure_wave=None, local_vars_configuration=None):  # noqa: E501
        """PipeRiskPropertyOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._pipe_model_id = None
        self._pipe_material = None
        self._pipe_age = None
        self._interface_type = None
        self._pipe_broken_num = None
        self._earthing_type = None
        self._road_load = None
        self._pressure_wave = None
        self.discriminator = None

        if id is not None:
            self.id = id
        self.pipe_model_id = pipe_model_id
        if pipe_material is not None:
            self.pipe_material = pipe_material
        if pipe_age is not None:
            self.pipe_age = pipe_age
        if interface_type is not None:
            self.interface_type = interface_type
        if pipe_broken_num is not None:
            self.pipe_broken_num = pipe_broken_num
        if earthing_type is not None:
            self.earthing_type = earthing_type
        if road_load is not None:
            self.road_load = road_load
        if pressure_wave is not None:
            self.pressure_wave = pressure_wave

    @property
    def id(self):
        """Gets the id of this PipeRiskPropertyOutput.  # noqa: E501


        :return: The id of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PipeRiskPropertyOutput.


        :param id: The id of this PipeRiskPropertyOutput.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def pipe_model_id(self):
        """Gets the pipe_model_id of this PipeRiskPropertyOutput.  # noqa: E501

        管道模型id  # noqa: E501

        :return: The pipe_model_id of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: str
        """
        return self._pipe_model_id

    @pipe_model_id.setter
    def pipe_model_id(self, pipe_model_id):
        """Sets the pipe_model_id of this PipeRiskPropertyOutput.

        管道模型id  # noqa: E501

        :param pipe_model_id: The pipe_model_id of this PipeRiskPropertyOutput.  # noqa: E501
        :type: str
        """

        self._pipe_model_id = pipe_model_id

    @property
    def pipe_material(self):
        """Gets the pipe_material of this PipeRiskPropertyOutput.  # noqa: E501

        管材  # noqa: E501

        :return: The pipe_material of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._pipe_material

    @pipe_material.setter
    def pipe_material(self, pipe_material):
        """Sets the pipe_material of this PipeRiskPropertyOutput.

        管材  # noqa: E501

        :param pipe_material: The pipe_material of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._pipe_material = pipe_material

    @property
    def pipe_age(self):
        """Gets the pipe_age of this PipeRiskPropertyOutput.  # noqa: E501

        管龄  # noqa: E501

        :return: The pipe_age of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._pipe_age

    @pipe_age.setter
    def pipe_age(self, pipe_age):
        """Sets the pipe_age of this PipeRiskPropertyOutput.

        管龄  # noqa: E501

        :param pipe_age: The pipe_age of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._pipe_age = pipe_age

    @property
    def interface_type(self):
        """Gets the interface_type of this PipeRiskPropertyOutput.  # noqa: E501

        接口类型  # noqa: E501

        :return: The interface_type of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._interface_type

    @interface_type.setter
    def interface_type(self, interface_type):
        """Sets the interface_type of this PipeRiskPropertyOutput.

        接口类型  # noqa: E501

        :param interface_type: The interface_type of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._interface_type = interface_type

    @property
    def pipe_broken_num(self):
        """Gets the pipe_broken_num of this PipeRiskPropertyOutput.  # noqa: E501

        爆管次数  # noqa: E501

        :return: The pipe_broken_num of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._pipe_broken_num

    @pipe_broken_num.setter
    def pipe_broken_num(self, pipe_broken_num):
        """Sets the pipe_broken_num of this PipeRiskPropertyOutput.

        爆管次数  # noqa: E501

        :param pipe_broken_num: The pipe_broken_num of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._pipe_broken_num = pipe_broken_num

    @property
    def earthing_type(self):
        """Gets the earthing_type of this PipeRiskPropertyOutput.  # noqa: E501

        覆土类型  # noqa: E501

        :return: The earthing_type of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._earthing_type

    @earthing_type.setter
    def earthing_type(self, earthing_type):
        """Sets the earthing_type of this PipeRiskPropertyOutput.

        覆土类型  # noqa: E501

        :param earthing_type: The earthing_type of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._earthing_type = earthing_type

    @property
    def road_load(self):
        """Gets the road_load of this PipeRiskPropertyOutput.  # noqa: E501

        路面负荷  # noqa: E501

        :return: The road_load of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._road_load

    @road_load.setter
    def road_load(self, road_load):
        """Sets the road_load of this PipeRiskPropertyOutput.

        路面负荷  # noqa: E501

        :param road_load: The road_load of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._road_load = road_load

    @property
    def pressure_wave(self):
        """Gets the pressure_wave of this PipeRiskPropertyOutput.  # noqa: E501

        压力波动  # noqa: E501

        :return: The pressure_wave of this PipeRiskPropertyOutput.  # noqa: E501
        :rtype: float
        """
        return self._pressure_wave

    @pressure_wave.setter
    def pressure_wave(self, pressure_wave):
        """Sets the pressure_wave of this PipeRiskPropertyOutput.

        压力波动  # noqa: E501

        :param pressure_wave: The pressure_wave of this PipeRiskPropertyOutput.  # noqa: E501
        :type: float
        """

        self._pressure_wave = pressure_wave

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipeRiskPropertyOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PipeRiskPropertyOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa
"""
    IoT服务

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_iot_service.models.add_asset_input import AddAssetInput
from dhicn_iot_service.models.add_device_indicator_input import AddDeviceIndicatorInput
from dhicn_iot_service.models.add_device_input import AddDeviceInput
from dhicn_iot_service.models.add_device_maintenance_input import AddDeviceMaintenanceInput
from dhicn_iot_service.models.add_group_input import AddGroupInput
from dhicn_iot_service.models.add_iot_group_equip_rel import AddIotGroupEquipRel
from dhicn_iot_service.models.add_model_point_data_type_input import AddModelPointDataTypeInput
from dhicn_iot_service.models.add_model_points_input import AddModelPointsInput
from dhicn_iot_service.models.add_opc_ua_com_input import AddOpcUaComInput
from dhicn_iot_service.models.add_opc_ua_config_input import AddOpcUaConfigInput
from dhicn_iot_service.models.add_opc_ua_pub_sub_input import AddOpcUaPubSubInput
from dhicn_iot_service.models.add_or_update_online_datas_input import AddOrUpdateOnlineDatasInput
from dhicn_iot_service.models.add_reality_model_relation_input import AddRealityModelRelationInput
from dhicn_iot_service.models.asset_details_output import AssetDetailsOutput
from dhicn_iot_service.models.asset_info_output import AssetInfoOutput
from dhicn_iot_service.models.asset_info_output_page import AssetInfoOutputPage
from dhicn_iot_service.models.asset_rel import AssetRel
from dhicn_iot_service.models.asset_relations_input import AssetRelationsInput
from dhicn_iot_service.models.attributes_param_item import AttributesParamItem
from dhicn_iot_service.models.data_type_mapping_item import DataTypeMappingItem
from dhicn_iot_service.models.delete_assets_input import DeleteAssetsInput
from dhicn_iot_service.models.delete_devices_input import DeleteDevicesInput
from dhicn_iot_service.models.device_indicator_input import DeviceIndicatorInput
from dhicn_iot_service.models.device_indicator_output import DeviceIndicatorOutput
from dhicn_iot_service.models.device_infos_input_with_attr import DeviceInfosInputWithAttr
from dhicn_iot_service.models.device_infos_output import DeviceInfosOutput
from dhicn_iot_service.models.device_infos_output_page import DeviceInfosOutputPage
from dhicn_iot_service.models.device_keys_output import DeviceKeysOutput
from dhicn_iot_service.models.device_maintenance_output import DeviceMaintenanceOutput
from dhicn_iot_service.models.device_rel import DeviceRel
from dhicn_iot_service.models.get_all_group_equip_rel_input import GetAllGroupEquipRelInput
from dhicn_iot_service.models.get_all_group_equip_rel_output import GetAllGroupEquipRelOutput
from dhicn_iot_service.models.get_attributes_input import GetAttributesInput
from dhicn_iot_service.models.get_multi_device_indicator_output import GetMultiDeviceIndicatorOutput
from dhicn_iot_service.models.get_online_ts_data_input import GetOnlineTsDataInput
from dhicn_iot_service.models.group_equip_rel_output import GroupEquipRelOutput
from dhicn_iot_service.models.group_tree_output import GroupTreeOutput
from dhicn_iot_service.models.his_data_search_input import HisDataSearchInput
from dhicn_iot_service.models.history_search_record_output import HistorySearchRecordOutput
from dhicn_iot_service.models.in_point_map import InPointMap
from dhicn_iot_service.models.init_opc_ua_config_input import InitOpcUaConfigInput
from dhicn_iot_service.models.inline_object import InlineObject
from dhicn_iot_service.models.inline_object1 import InlineObject1
from dhicn_iot_service.models.inline_object2 import InlineObject2
from dhicn_iot_service.models.inline_object3 import InlineObject3
from dhicn_iot_service.models.inline_object4 import InlineObject4
from dhicn_iot_service.models.iot_group_config_output import IotGroupConfigOutput
from dhicn_iot_service.models.iot_group_equip_rel_output import IotGroupEquipRelOutput
from dhicn_iot_service.models.latest_time_series_input import LatestTimeSeriesInput
from dhicn_iot_service.models.latest_time_series_output import LatestTimeSeriesOutput
from dhicn_iot_service.models.measure_data_input import MeasureDataInput
from dhicn_iot_service.models.mock_device_data_input import MockDeviceDataInput
from dhicn_iot_service.models.mock_device_info_input import MockDeviceInfoInput
from dhicn_iot_service.models.model_boundary_config_format import ModelBoundaryConfigFormat
from dhicn_iot_service.models.model_point_attribute_output import ModelPointAttributeOutput
from dhicn_iot_service.models.model_point_output import ModelPointOutput
from dhicn_iot_service.models.model_result_output import ModelResultOutput
from dhicn_iot_service.models.modify_online_processed_datas_input import ModifyOnlineProcessedDatasInput
from dhicn_iot_service.models.notify_params import NotifyParams
from dhicn_iot_service.models.opc_ua_com_assembly_info import OpcUaComAssemblyInfo
from dhicn_iot_service.models.opc_ua_com_para import OpcUaComPara
from dhicn_iot_service.models.opc_ua_pub_sub_para import OpcUaPubSubPara
from dhicn_iot_service.models.point_data_type_info import PointDataTypeInfo
from dhicn_iot_service.models.point_map_assembly_info import PointMapAssemblyInfo
from dhicn_iot_service.models.query_by_time import QueryByTime
from dhicn_iot_service.models.query_device_detail_input import QueryDeviceDetailInput
from dhicn_iot_service.models.query_ids_input import QueryIdsInput
from dhicn_iot_service.models.query_maintenance_input import QueryMaintenanceInput
from dhicn_iot_service.models.query_opc_ua_com_input import QueryOpcUaComInput
from dhicn_iot_service.models.query_opc_ua_config_output import QueryOpcUaConfigOutput
from dhicn_iot_service.models.query_opc_ua_pub_sub_input import QueryOpcUaPubSubInput
from dhicn_iot_service.models.read_node_input import ReadNodeInput
from dhicn_iot_service.models.save_device_attribute_values_input import SaveDeviceAttributeValuesInput
from dhicn_iot_service.models.save_history_search_record_input import SaveHistorySearchRecordInput
from dhicn_iot_service.models.save_out_point_map_input import SaveOutPointMapInput
from dhicn_iot_service.models.save_telemetry_data_input import SaveTelemetryDataInput
from dhicn_iot_service.models.save_telemetry_struct_data_batch_input import SaveTelemetryStructDataBatchInput
from dhicn_iot_service.models.search_category_output import SearchCategoryOutput
from dhicn_iot_service.models.search_condition_output import SearchConditionOutput
from dhicn_iot_service.models.search_in_out_point_map_assembly_input import SearchInOutPointMapAssemblyInput
from dhicn_iot_service.models.search_indicator import SearchIndicator
from dhicn_iot_service.models.search_output import SearchOutput
from dhicn_iot_service.models.string_list_result import StringListResult
from dhicn_iot_service.models.string_string_key_value import StringStringKeyValue
from dhicn_iot_service.models.timeseries_batch_for_v3_input import TimeseriesBatchForV3Input
from dhicn_iot_service.models.timeseries_batch_for_v3_output import TimeseriesBatchForV3Output
from dhicn_iot_service.models.timeseries_batch_output import TimeseriesBatchOutput
from dhicn_iot_service.models.timeseries_input import TimeseriesInput
from dhicn_iot_service.models.ts_data_input_output import TsDataInputOutput
from dhicn_iot_service.models.update_asset_input import UpdateAssetInput
from dhicn_iot_service.models.update_device_input import UpdateDeviceInput
from dhicn_iot_service.models.update_device_maintenance_input import UpdateDeviceMaintenanceInput
from dhicn_iot_service.models.update_group_input import UpdateGroupInput
from dhicn_iot_service.models.update_latest_tag_input import UpdateLatestTagInput
from dhicn_iot_service.models.update_model_point_data_type_input import UpdateModelPointDataTypeInput
from dhicn_iot_service.models.update_opc_ua_config_input import UpdateOpcUaConfigInput
from dhicn_iot_service.models.write_node_input import WriteNodeInput



# coding: utf-8

# flake8: noqa
"""
    scenario-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from dhicn_scenario_manager_service.models.add_libraries_para import AddLibrariesPara
from dhicn_scenario_manager_service.models.business_type_enum import BusinessTypeEnum
from dhicn_scenario_manager_service.models.create_root_scenario_group_para import CreateRootScenarioGroupPara
from dhicn_scenario_manager_service.models.create_scenario_by_group_para2 import CreateScenarioByGroupPara2
from dhicn_scenario_manager_service.models.create_scenario_from_file_para2 import CreateScenarioFromFilePara2
from dhicn_scenario_manager_service.models.create_scenario_group_para import CreateScenarioGroupPara
from dhicn_scenario_manager_service.models.create_scenario_para2 import CreateScenarioPara2
from dhicn_scenario_manager_service.models.create_template_scenario_by_min_io_para2 import CreateTemplateScenarioByMinIoPara2
from dhicn_scenario_manager_service.models.create_template_scenario_para2 import CreateTemplateScenarioPara2
from dhicn_scenario_manager_service.models.delete_libraries_para import DeleteLibrariesPara
from dhicn_scenario_manager_service.models.delete_scenario_group_para import DeleteScenarioGroupPara
from dhicn_scenario_manager_service.models.delete_scenario_para import DeleteScenarioPara
from dhicn_scenario_manager_service.models.group import Group
from dhicn_scenario_manager_service.models.library import Library
from dhicn_scenario_manager_service.models.library_type_enum import LibraryTypeEnum
from dhicn_scenario_manager_service.models.model_file_result import ModelFileResult
from dhicn_scenario_manager_service.models.model_type_enum import ModelTypeEnum
from dhicn_scenario_manager_service.models.rename_scenario_group_para import RenameScenarioGroupPara
from dhicn_scenario_manager_service.models.rename_scenario_para import RenameScenarioPara
from dhicn_scenario_manager_service.models.scenario import Scenario
from dhicn_scenario_manager_service.models.turn_on_template_para import TurnOnTemplatePara
from dhicn_scenario_manager_service.models.update_library_para import UpdateLibraryPara
from dhicn_scenario_manager_service.models.update_scenario_para import UpdateScenarioPara



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class ControlDevicesTs(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'indicator': 'str',
        'actual_weir_height_ts_pairs': 'TsPairs',
        'suggest_weir_height_ts_pairs': 'TsPairs',
        'control_ts_pairs': 'TsPairs',
        'data_issued_ts_pairs': 'TsPairs'
    }

    attribute_map = {
        'indicator': 'indicator',
        'actual_weir_height_ts_pairs': 'actualWeirHeightTsPairs',
        'suggest_weir_height_ts_pairs': 'suggestWeirHeightTsPairs',
        'control_ts_pairs': 'controlTsPairs',
        'data_issued_ts_pairs': 'dataIssuedTsPairs'
    }

    def __init__(self, indicator=None, actual_weir_height_ts_pairs=None, suggest_weir_height_ts_pairs=None, control_ts_pairs=None, data_issued_ts_pairs=None, local_vars_configuration=None):  # noqa: E501
        """ControlDevicesTs - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._indicator = None
        self._actual_weir_height_ts_pairs = None
        self._suggest_weir_height_ts_pairs = None
        self._control_ts_pairs = None
        self._data_issued_ts_pairs = None
        self.discriminator = None

        self.indicator = indicator
        if actual_weir_height_ts_pairs is not None:
            self.actual_weir_height_ts_pairs = actual_weir_height_ts_pairs
        if suggest_weir_height_ts_pairs is not None:
            self.suggest_weir_height_ts_pairs = suggest_weir_height_ts_pairs
        if control_ts_pairs is not None:
            self.control_ts_pairs = control_ts_pairs
        if data_issued_ts_pairs is not None:
            self.data_issued_ts_pairs = data_issued_ts_pairs

    @property
    def indicator(self):
        """Gets the indicator of this ControlDevicesTs.  # noqa: E501


        :return: The indicator of this ControlDevicesTs.  # noqa: E501
        :rtype: str
        """
        return self._indicator

    @indicator.setter
    def indicator(self, indicator):
        """Sets the indicator of this ControlDevicesTs.


        :param indicator: The indicator of this ControlDevicesTs.  # noqa: E501
        :type: str
        """

        self._indicator = indicator

    @property
    def actual_weir_height_ts_pairs(self):
        """Gets the actual_weir_height_ts_pairs of this ControlDevicesTs.  # noqa: E501


        :return: The actual_weir_height_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :rtype: TsPairs
        """
        return self._actual_weir_height_ts_pairs

    @actual_weir_height_ts_pairs.setter
    def actual_weir_height_ts_pairs(self, actual_weir_height_ts_pairs):
        """Sets the actual_weir_height_ts_pairs of this ControlDevicesTs.


        :param actual_weir_height_ts_pairs: The actual_weir_height_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :type: TsPairs
        """

        self._actual_weir_height_ts_pairs = actual_weir_height_ts_pairs

    @property
    def suggest_weir_height_ts_pairs(self):
        """Gets the suggest_weir_height_ts_pairs of this ControlDevicesTs.  # noqa: E501


        :return: The suggest_weir_height_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :rtype: TsPairs
        """
        return self._suggest_weir_height_ts_pairs

    @suggest_weir_height_ts_pairs.setter
    def suggest_weir_height_ts_pairs(self, suggest_weir_height_ts_pairs):
        """Sets the suggest_weir_height_ts_pairs of this ControlDevicesTs.


        :param suggest_weir_height_ts_pairs: The suggest_weir_height_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :type: TsPairs
        """

        self._suggest_weir_height_ts_pairs = suggest_weir_height_ts_pairs

    @property
    def control_ts_pairs(self):
        """Gets the control_ts_pairs of this ControlDevicesTs.  # noqa: E501


        :return: The control_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :rtype: TsPairs
        """
        return self._control_ts_pairs

    @control_ts_pairs.setter
    def control_ts_pairs(self, control_ts_pairs):
        """Sets the control_ts_pairs of this ControlDevicesTs.


        :param control_ts_pairs: The control_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :type: TsPairs
        """

        self._control_ts_pairs = control_ts_pairs

    @property
    def data_issued_ts_pairs(self):
        """Gets the data_issued_ts_pairs of this ControlDevicesTs.  # noqa: E501


        :return: The data_issued_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :rtype: TsPairs
        """
        return self._data_issued_ts_pairs

    @data_issued_ts_pairs.setter
    def data_issued_ts_pairs(self, data_issued_ts_pairs):
        """Sets the data_issued_ts_pairs of this ControlDevicesTs.


        :param data_issued_ts_pairs: The data_issued_ts_pairs of this ControlDevicesTs.  # noqa: E501
        :type: TsPairs
        """

        self._data_issued_ts_pairs = data_issued_ts_pairs

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ControlDevicesTs):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ControlDevicesTs):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    result-analysis-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_result_analysis_service.configuration import Configuration


class PipeProfileItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'pipe_id': 'str',
        'diameter': 'float',
        'length': 'float',
        'from_node': 'NodeItem',
        'to_node': 'NodeItem'
    }

    attribute_map = {
        'pipe_id': 'pipeID',
        'diameter': 'diameter',
        'length': 'length',
        'from_node': 'fromNode',
        'to_node': 'toNode'
    }

    def __init__(self, pipe_id=None, diameter=None, length=None, from_node=None, to_node=None, local_vars_configuration=None):  # noqa: E501
        """PipeProfileItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._pipe_id = None
        self._diameter = None
        self._length = None
        self._from_node = None
        self._to_node = None
        self.discriminator = None

        self.pipe_id = pipe_id
        if diameter is not None:
            self.diameter = diameter
        if length is not None:
            self.length = length
        if from_node is not None:
            self.from_node = from_node
        if to_node is not None:
            self.to_node = to_node

    @property
    def pipe_id(self):
        """Gets the pipe_id of this PipeProfileItem.  # noqa: E501

        管段ID pipe ID  # noqa: E501

        :return: The pipe_id of this PipeProfileItem.  # noqa: E501
        :rtype: str
        """
        return self._pipe_id

    @pipe_id.setter
    def pipe_id(self, pipe_id):
        """Sets the pipe_id of this PipeProfileItem.

        管段ID pipe ID  # noqa: E501

        :param pipe_id: The pipe_id of this PipeProfileItem.  # noqa: E501
        :type: str
        """

        self._pipe_id = pipe_id

    @property
    def diameter(self):
        """Gets the diameter of this PipeProfileItem.  # noqa: E501

        管径或管高 pipe diameter or height  # noqa: E501

        :return: The diameter of this PipeProfileItem.  # noqa: E501
        :rtype: float
        """
        return self._diameter

    @diameter.setter
    def diameter(self, diameter):
        """Sets the diameter of this PipeProfileItem.

        管径或管高 pipe diameter or height  # noqa: E501

        :param diameter: The diameter of this PipeProfileItem.  # noqa: E501
        :type: float
        """

        self._diameter = diameter

    @property
    def length(self):
        """Gets the length of this PipeProfileItem.  # noqa: E501

        管长 pipe length  # noqa: E501

        :return: The length of this PipeProfileItem.  # noqa: E501
        :rtype: float
        """
        return self._length

    @length.setter
    def length(self, length):
        """Sets the length of this PipeProfileItem.

        管长 pipe length  # noqa: E501

        :param length: The length of this PipeProfileItem.  # noqa: E501
        :type: float
        """

        self._length = length

    @property
    def from_node(self):
        """Gets the from_node of this PipeProfileItem.  # noqa: E501


        :return: The from_node of this PipeProfileItem.  # noqa: E501
        :rtype: NodeItem
        """
        return self._from_node

    @from_node.setter
    def from_node(self, from_node):
        """Sets the from_node of this PipeProfileItem.


        :param from_node: The from_node of this PipeProfileItem.  # noqa: E501
        :type: NodeItem
        """

        self._from_node = from_node

    @property
    def to_node(self):
        """Gets the to_node of this PipeProfileItem.  # noqa: E501


        :return: The to_node of this PipeProfileItem.  # noqa: E501
        :rtype: NodeItem
        """
        return self._to_node

    @to_node.setter
    def to_node(self, to_node):
        """Sets the to_node of this PipeProfileItem.


        :param to_node: The to_node of this PipeProfileItem.  # noqa: E501
        :type: NodeItem
        """

        self._to_node = to_node

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PipeProfileItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, PipeProfileItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    accident-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_accident_management_service.configuration import Configuration


class ComponentValueInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'component_id': 'str',
        'key_id': 'str',
        'key_name': 'str',
        'str_value': 'str',
        'json_value': 'str',
        'bool_value': 'bool',
        'double_value': 'float',
        'long_value': 'int',
        'time_value': 'datetime',
        'ts_value': 'str'
    }

    attribute_map = {
        'component_id': 'componentId',
        'key_id': 'keyId',
        'key_name': 'keyName',
        'str_value': 'str_Value',
        'json_value': 'json_Value',
        'bool_value': 'bool_Value',
        'double_value': 'double_Value',
        'long_value': 'long_Value',
        'time_value': 'time_Value',
        'ts_value': 'ts_Value'
    }

    def __init__(self, component_id=None, key_id=None, key_name=None, str_value=None, json_value=None, bool_value=None, double_value=None, long_value=None, time_value=None, ts_value=None, local_vars_configuration=None):  # noqa: E501
        """ComponentValueInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._component_id = None
        self._key_id = None
        self._key_name = None
        self._str_value = None
        self._json_value = None
        self._bool_value = None
        self._double_value = None
        self._long_value = None
        self._time_value = None
        self._ts_value = None
        self.discriminator = None

        if component_id is not None:
            self.component_id = component_id
        if key_id is not None:
            self.key_id = key_id
        self.key_name = key_name
        self.str_value = str_value
        self.json_value = json_value
        self.bool_value = bool_value
        self.double_value = double_value
        self.long_value = long_value
        self.time_value = time_value
        self.ts_value = ts_value

    @property
    def component_id(self):
        """Gets the component_id of this ComponentValueInfo.  # noqa: E501

        污染物ID pollutant id  # noqa: E501

        :return: The component_id of this ComponentValueInfo.  # noqa: E501
        :rtype: str
        """
        return self._component_id

    @component_id.setter
    def component_id(self, component_id):
        """Sets the component_id of this ComponentValueInfo.

        污染物ID pollutant id  # noqa: E501

        :param component_id: The component_id of this ComponentValueInfo.  # noqa: E501
        :type: str
        """

        self._component_id = component_id

    @property
    def key_id(self):
        """Gets the key_id of this ComponentValueInfo.  # noqa: E501

        污染物属性ID pollutant attribute id  # noqa: E501

        :return: The key_id of this ComponentValueInfo.  # noqa: E501
        :rtype: str
        """
        return self._key_id

    @key_id.setter
    def key_id(self, key_id):
        """Sets the key_id of this ComponentValueInfo.

        污染物属性ID pollutant attribute id  # noqa: E501

        :param key_id: The key_id of this ComponentValueInfo.  # noqa: E501
        :type: str
        """

        self._key_id = key_id

    @property
    def key_name(self):
        """Gets the key_name of this ComponentValueInfo.  # noqa: E501

        污染物属性名称 pollutant attribute name  # noqa: E501

        :return: The key_name of this ComponentValueInfo.  # noqa: E501
        :rtype: str
        """
        return self._key_name

    @key_name.setter
    def key_name(self, key_name):
        """Sets the key_name of this ComponentValueInfo.

        污染物属性名称 pollutant attribute name  # noqa: E501

        :param key_name: The key_name of this ComponentValueInfo.  # noqa: E501
        :type: str
        """

        self._key_name = key_name

    @property
    def str_value(self):
        """Gets the str_value of this ComponentValueInfo.  # noqa: E501

        字符串类型值 value in string format  # noqa: E501

        :return: The str_value of this ComponentValueInfo.  # noqa: E501
        :rtype: str
        """
        return self._str_value

    @str_value.setter
    def str_value(self, str_value):
        """Sets the str_value of this ComponentValueInfo.

        字符串类型值 value in string format  # noqa: E501

        :param str_value: The str_value of this ComponentValueInfo.  # noqa: E501
        :type: str
        """

        self._str_value = str_value

    @property
    def json_value(self):
        """Gets the json_value of this ComponentValueInfo.  # noqa: E501

        JSON格式字符串类型值 value in JSON string format  # noqa: E501

        :return: The json_value of this ComponentValueInfo.  # noqa: E501
        :rtype: str
        """
        return self._json_value

    @json_value.setter
    def json_value(self, json_value):
        """Sets the json_value of this ComponentValueInfo.

        JSON格式字符串类型值 value in JSON string format  # noqa: E501

        :param json_value: The json_value of this ComponentValueInfo.  # noqa: E501
        :type: str
        """

        self._json_value = json_value

    @property
    def bool_value(self):
        """Gets the bool_value of this ComponentValueInfo.  # noqa: E501

        布尔类型值 value in Bool format  # noqa: E501

        :return: The bool_value of this ComponentValueInfo.  # noqa: E501
        :rtype: bool
        """
        return self._bool_value

    @bool_value.setter
    def bool_value(self, bool_value):
        """Sets the bool_value of this ComponentValueInfo.

        布尔类型值 value in Bool format  # noqa: E501

        :param bool_value: The bool_value of this ComponentValueInfo.  # noqa: E501
        :type: bool
        """

        self._bool_value = bool_value

    @property
    def double_value(self):
        """Gets the double_value of this ComponentValueInfo.  # noqa: E501

        双精度浮点类型值 value in Double format  # noqa: E501

        :return: The double_value of this ComponentValueInfo.  # noqa: E501
        :rtype: float
        """
        return self._double_value

    @double_value.setter
    def double_value(self, double_value):
        """Sets the double_value of this ComponentValueInfo.

        双精度浮点类型值 value in Double format  # noqa: E501

        :param double_value: The double_value of this ComponentValueInfo.  # noqa: E501
        :type: float
        """

        self._double_value = double_value

    @property
    def long_value(self):
        """Gets the long_value of this ComponentValueInfo.  # noqa: E501

        长整形类型值 value in Long format  # noqa: E501

        :return: The long_value of this ComponentValueInfo.  # noqa: E501
        :rtype: int
        """
        return self._long_value

    @long_value.setter
    def long_value(self, long_value):
        """Sets the long_value of this ComponentValueInfo.

        长整形类型值 value in Long format  # noqa: E501

        :param long_value: The long_value of this ComponentValueInfo.  # noqa: E501
        :type: int
        """

        self._long_value = long_value

    @property
    def time_value(self):
        """Gets the time_value of this ComponentValueInfo.  # noqa: E501

        时间类型值 value in DateTime format  # noqa: E501

        :return: The time_value of this ComponentValueInfo.  # noqa: E501
        :rtype: datetime
        """
        return self._time_value

    @time_value.setter
    def time_value(self, time_value):
        """Sets the time_value of this ComponentValueInfo.

        时间类型值 value in DateTime format  # noqa: E501

        :param time_value: The time_value of this ComponentValueInfo.  # noqa: E501
        :type: datetime
        """

        self._time_value = time_value

    @property
    def ts_value(self):
        """Gets the ts_value of this ComponentValueInfo.  # noqa: E501

        时间序列ID time series id  # noqa: E501

        :return: The ts_value of this ComponentValueInfo.  # noqa: E501
        :rtype: str
        """
        return self._ts_value

    @ts_value.setter
    def ts_value(self, ts_value):
        """Sets the ts_value of this ComponentValueInfo.

        时间序列ID time series id  # noqa: E501

        :param ts_value: The ts_value of this ComponentValueInfo.  # noqa: E501
        :type: str
        """

        self._ts_value = ts_value

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ComponentValueInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ComponentValueInfo):
            return True

        return self.to_dict() != other.to_dict()
